;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.5.0" "Cross-referencing commands" '((emacs "26.1")) :commit "1b99f2908b7d2c17dc1231f83f499fe460ba926a" :url "https://elpa.gnu.org/packages/xref.html")
